@@ -113,6 +113,9 @@ import org.apache.qpid.proton.engine.Session;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
+import static org.apache.activemq.artemis.protocol.amqp.connect.AMQPBrokerConnectionConstants.BROKER_CONNECTION_INFO;
+import static org.apache.activemq.artemis.protocol.amqp.connect.AMQPBrokerConnectionConstants.CONNECTION_NAME;
+import static org.apache.activemq.artemis.protocol.amqp.connect.AMQPBrokerConnectionConstants.NODE_ID;
 import static org.apache.activemq.artemis.protocol.amqp.proton.AmqpSupport.AMQP_LINK_INITIALIZER_KEY;
 import static org.apache.activemq.artemis.protocol.amqp.proton.AmqpSupport.verifyCapabilities;
 import static org.apache.activemq.artemis.protocol.amqp.proton.AmqpSupport.verifyOfferedCapabilities;
@@ -124,9 +127,9 @@ public class AMQPBrokerConnection implements ClientConnectionLifeCycleListener,
    private static final Logger logger = LoggerFactory.getLogger(MethodHandles.lookup().lookupClass());
 
    /**
-    * Default value for the core message tunneling feature that indicates if core protocol messages
-    * should be streamed as binary blobs as the payload of an custom AMQP message which avoids any
-    * conversions of the messages to / from AMQP.
+    * Default value for the core message tunneling feature that indicates if core protocol messages should be streamed
+    * as binary blobs as the payload of an custom AMQP message which avoids any conversions of the messages to / from
+    * AMQP.
     */
    public static final boolean DEFAULT_CORE_MESSAGE_TUNNELING_ENABLED = true;
 
@@ -157,12 +160,14 @@ public class AMQPBrokerConnection implements ClientConnectionLifeCycleListener,
    final Executor connectExecutor;
    final ScheduledExecutorService scheduledExecutorService;
 
-   /** This is just for logging.
-    *  the actual connection will come from the amqpConnection configuration*/
+   /**
+    * This is just for logging. the actual connection will come from the amqpConnection configuration
+    */
    String host;
 
-   /** This is just for logging.
-    *  the actual connection will come from the amqpConnection configuration*/
+   /**
+    * This is just for logging. the actual connection will come from the amqpConnection configuration
+    */
    int port;
 
    public AMQPBrokerConnection(AMQPBrokerConnectionManager bridgeManager,
@@ -194,6 +199,17 @@ public class AMQPBrokerConnection implements ClientConnectionLifeCycleListener,
       return brokerConnectConfiguration;
    }
 
+   @Override
+   public boolean isConnected() {
+      final NettyConnection connection = this.connection;
+
+      if (connection != null) {
+         return connection.isOpen();
+      } else {
+         return false;
+      }
+   }
+
    @Override
    public boolean isStarted() {
       return started;
@@ -208,49 +224,106 @@ public class AMQPBrokerConnection implements ClientConnectionLifeCycleListener,
    }
 
    @Override
-   public void stop() {
-      if (!started) return;
-      started = false;
-      if (protonRemotingConnection != null) {
-         protonRemotingConnection.fail(new ActiveMQException("Stopping Broker Connection"));
-         protonRemotingConnection = null;
-         connection = null;
-      }
-      ScheduledFuture<?> scheduledFuture = reconnectFuture;
-      reconnectFuture = null;
-      if (scheduledFuture != null) {
-         scheduledFuture.cancel(true);
-      }
-      if (brokerFederation != null) {
-         try {
-            brokerFederation.stop();
-         } catch (ActiveMQException e) {
-         }
-      }
-   }
-
-   @Override
-   public void start() throws Exception {
-      if (started) return;
-      started = true;
-      server.getConfiguration().registerBrokerPlugin(this);
+   public synchronized void initialize() throws Exception {
       try {
+         server.registerBrokerConnection(this);
+         server.getManagementService().registerBrokerConnection(this);
+
          if (brokerConnectConfiguration != null && brokerConnectConfiguration.getConnectionElements() != null) {
             for (AMQPBrokerConnectionElement connectionElement : brokerConnectConfiguration.getConnectionElements()) {
                final AMQPBrokerConnectionAddressType elementType = connectionElement.getType();
 
-               if (elementType == AMQPBrokerConnectionAddressType.MIRROR) {
-                  installMirrorController((AMQPMirrorBrokerConnectionElement) connectionElement, server);
-               } else if (elementType == AMQPBrokerConnectionAddressType.FEDERATION) {
+               if (elementType == AMQPBrokerConnectionAddressType.FEDERATION) {
                   installFederation((AMQPFederatedBrokerConnectionElement) connectionElement, server);
                }
             }
          }
       } catch (Throwable e) {
          logger.warn(e.getMessage(), e);
-         return;
       }
-      connectExecutor.execute(() -> doConnect());
+   }
+
+   @Override
+   public synchronized void start() throws Exception {
+      if (!started) {
+         started = true;
+         server.getConfiguration().registerBrokerPlugin(this);
+
+         try {
+            if (brokerConnectConfiguration != null && brokerConnectConfiguration.getConnectionElements() != null) {
+               for (AMQPBrokerConnectionElement connectionElement : brokerConnectConfiguration.getConnectionElements()) {
+                  final AMQPBrokerConnectionAddressType elementType = connectionElement.getType();
+
+                  // Preserve old behavior where mirror controller wasn't installed until the first time
+                  // the broker connection was started. This won't add a new controller if stopped and then
+                  // restarted, once added a controller cannot currently be rmoved.
+                  if (elementType == AMQPBrokerConnectionAddressType.MIRROR) {
+                     installMirrorController((AMQPMirrorBrokerConnectionElement) connectionElement, server);
+                  }
+               }
+            }
+         } catch (Throwable e) {
+            logger.warn(e.getMessage(), e);
+         }
+
+         if (brokerFederation != null) {
+            try {
+               brokerFederation.start();
+            } catch (ActiveMQException e) {
+               logger.warn("Error caught while starting federation instance.", e);
+            }
+         }
+
+         connectExecutor.execute(() -> doConnect());
+      }
+   }
+
+   @Override
+   public synchronized void stop() {
+      if (started) {
+         started = false;
+         server.getConfiguration().unRegisterBrokerPlugin(this);
+
+         if (protonRemotingConnection != null) {
+            protonRemotingConnection.fail(new ActiveMQException("Stopping Broker Connection"));
+            protonRemotingConnection = null;
+            connection = null;
+         }
+
+         final ScheduledFuture<?> scheduledFuture = reconnectFuture;
+         reconnectFuture = null;
+         if (scheduledFuture != null) {
+            scheduledFuture.cancel(true);
+         }
+
+         if (brokerFederation != null) {
+            try {
+               brokerFederation.stop();
+            } catch (ActiveMQException e) {
+               logger.debug("Error caught while stopping federation instance.", e);
+            }
+         }
+      }
+   }
+
+   @Override
+   public synchronized void shutdown() throws Exception {
+      try {
+         stop();
+      } finally {
+         if (brokerFederation != null) {
+            try {
+               brokerFederation.shutdown();
+            } catch (ActiveMQException e) {
+               logger.debug("Error caught while shutting down federation instance.", e);
+            } finally {
+               brokerFederation = null;
+            }
+         }
+
+         server.unregisterBrokerConnection(this);
+         server.getManagementService().unregisterBrokerConnection(getName());
+      }
    }
 
    public ActiveMQServer getServer() {
@@ -305,16 +378,13 @@ public class AMQPBrokerConnection implements ClientConnectionLifeCycleListener,
    }
 
    /**
-    * Adds a remote link closed event interceptor that can intercept the closed event and if it
-    * returns true indicate that the close has been handled and that normal broker connection
-    * remote link closed handling should be ignored.
+    * Adds a remote link closed event interceptor that can intercept the closed event and if it returns {@code true}
+    * indicate that the close has been handled and that normal broker connection remote link closed handling should be
+    * ignored.
     *
-    * @param id
-    *    A unique Id value that identifies the intercepter for later removal.
-    * @param interceptor
-    *    The predicate that will be called for any link close.
-    *
-    * @return this broker connection instance.
+    * @param id          A unique Id value that identifies the intercepter for later removal.
+    * @param interceptor The predicate that will be called for any link close.
+    * @return this broker connection instance
     */
    public AMQPBrokerConnection addLinkClosedInterceptor(String id, Predicate<Link> interceptor) {
       linkClosedInterceptors.put(id, interceptor);
@@ -324,10 +394,8 @@ public class AMQPBrokerConnection implements ClientConnectionLifeCycleListener,
    /**
     * Remove a previously registered link close interceptor from the broker connection.
     *
-    * @param id
-    *   The id of the interceptor to remove
-    *
-    * @return this broker connection instance.
+    * @param id The id of the interceptor to remove
+    * @return this broker connection instance
     */
    public AMQPBrokerConnection removeLinkClosedInterceptor(String id) {
       linkClosedInterceptors.remove(id);
@@ -392,8 +460,17 @@ public class AMQPBrokerConnection implements ClientConnectionLifeCycleListener,
 
          ClientSASLFactory saslFactory = new SaslFactory(connection, brokerConnectConfiguration);
 
+         final Map<String, Object> brokerConnectionInfo = new HashMap<>();
+
+         brokerConnectionInfo.put(CONNECTION_NAME, getName());
+         brokerConnectionInfo.put(NODE_ID, server.getNodeID().toString());
+
+         final Map<Symbol, Object> brokerConnectionProperties = new HashMap<>();
+
+         brokerConnectionProperties.put(BROKER_CONNECTION_INFO, brokerConnectionInfo);
+
          NettyConnectorCloseHandler connectorCloseHandler = new NettyConnectorCloseHandler(connector, connectExecutor);
-         ConnectionEntry entry = protonProtocolManager.createOutgoingConnectionEntry(connection, saslFactory);
+         ConnectionEntry entry = protonProtocolManager.createOutgoingConnectionEntry(connection, saslFactory, brokerConnectionProperties);
          server.getRemotingService().addConnectionEntry(connection, entry);
          protonRemotingConnection = (ActiveMQProtonRemotingConnection) entry.connection;
          protonRemotingConnection.getAmqpConnection().addLinkRemoteCloseListener(getName(), this::linkClosed);
@@ -415,8 +492,8 @@ public class AMQPBrokerConnection implements ClientConnectionLifeCycleListener,
             Stream<Binding> bindingStream = server.getPostOffice().getAllBindings();
 
             bindingStream.forEach(binding -> {
-               if (binding instanceof QueueBinding) {
-                  Queue queue = ((QueueBinding) binding).getQueue();
+               if (binding instanceof QueueBinding queueBinding) {
+                  Queue queue = queueBinding.getQueue();
                   for (AMQPBrokerConnectionElement connectionElement : brokerConnectConfiguration.getConnectionElements()) {
                      validateMatching(queue, connectionElement);
                   }
@@ -450,9 +527,9 @@ public class AMQPBrokerConnection implements ClientConnectionLifeCycleListener,
                                 null,
                                 requiredOfferedCapabilities);
                } else if (connectionElement.getType() == AMQPBrokerConnectionAddressType.FEDERATION) {
-                  // Starting the Federation triggers rebuild of federation links
+                  // Signal the Federation instance to start a rebuild of federation links
                   // based on current broker state.
-                  brokerFederation.handleConnectionRestored(protonRemotingConnection.getAmqpConnection(), sessionContext);
+                  brokerFederation.connectionRestored(protonRemotingConnection.getAmqpConnection(), sessionContext);
                }
             }
          }
@@ -500,15 +577,14 @@ public class AMQPBrokerConnection implements ClientConnectionLifeCycleListener,
       MirrorController currentMirrorController = server.getMirrorController();
 
       // This following block is to avoid a duplicate on mirror controller
-      if (currentMirrorController != null && currentMirrorController instanceof AMQPMirrorControllerSource) {
-         Queue queue = checkCurrentMirror(this, (AMQPMirrorControllerSource) currentMirrorController);
+      if (currentMirrorController != null && currentMirrorController instanceof AMQPMirrorControllerSource source) {
+         Queue queue = checkCurrentMirror(this, source);
          // on this case we already had a mirror installed before, we won't duplicate it
          if (queue != null) {
             queue.deliverAsync();
             return queue;
          }
-      } else if (currentMirrorController != null && currentMirrorController instanceof AMQPMirrorControllerAggregation) {
-         AMQPMirrorControllerAggregation aggregation = (AMQPMirrorControllerAggregation) currentMirrorController;
+      } else if (currentMirrorController != null && currentMirrorController instanceof AMQPMirrorControllerAggregation aggregation) {
 
          for (AMQPMirrorControllerSource source : aggregation.getPartitions()) {
             Queue queue = checkCurrentMirror(this, source);
@@ -568,10 +644,10 @@ public class AMQPBrokerConnection implements ClientConnectionLifeCycleListener,
          server.installMirrorController(newPartition);
       } else {
          // Replace a standard implementation by an aggregated supporting multiple targets
-         if (currentMirrorController instanceof AMQPMirrorControllerSource) {
+         if (currentMirrorController instanceof AMQPMirrorControllerSource source) {
             // replacing the simple mirror control for an aggregator
             AMQPMirrorControllerAggregation remoteAggregation = new AMQPMirrorControllerAggregation();
-            remoteAggregation.addPartition((AMQPMirrorControllerSource) currentMirrorController);
+            remoteAggregation.addPartition(source);
             currentMirrorController = remoteAggregation;
             server.installMirrorController(remoteAggregation);
          }
@@ -594,6 +670,9 @@ public class AMQPBrokerConnection implements ClientConnectionLifeCycleListener,
    private void installFederation(AMQPFederatedBrokerConnectionElement connectionElement, ActiveMQServer server) throws Exception {
       final AMQPFederationSource federation = new AMQPFederationSource(connectionElement.getName(), connectionElement.getProperties(), this);
 
+      // Ensure basic federation resources are initialized before adding policies and moving on
+      federation.initialize();
+
       // Broker federation configuration for local resources that should be receiving from remote resources
       // when there is local demand.
       final Set<AMQPFederationAddressPolicyElement> localAddressPolicies = connectionElement.getLocalAddressPolicies();
@@ -629,7 +708,6 @@ public class AMQPBrokerConnection implements ClientConnectionLifeCycleListener,
       }
 
       this.brokerFederation = federation;
-      this.brokerFederation.start();
    }
 
    private void connectReceiver(ActiveMQProtonRemotingConnection protonRemotingConnection,
@@ -731,7 +809,7 @@ public class AMQPBrokerConnection implements ClientConnectionLifeCycleListener,
                               throw new ActiveMQAMQPInternalErrorException(e.getMessage(), e);
                            }
 
-                           flow();
+                           topUpCreditIfNeeded();
                         }
                      };
                   });
@@ -783,7 +861,7 @@ public class AMQPBrokerConnection implements ClientConnectionLifeCycleListener,
             source.setAddress(queue.getAddress().toString());
             sender.setSource(source);
             if (brokerID != null) {
-               HashMap<Symbol, Object> mapProperties = new HashMap<>(1, 1); // this map is expected to have a single element, so load factor = 1
+               Map<Symbol, Object> mapProperties = new HashMap<>(1, 1); // this map is expected to have a single element, so load factor = 1
                mapProperties.put(AMQPMirrorControllerSource.BROKER_ID, brokerID);
                sender.setProperties(mapProperties);
             }
@@ -860,30 +938,24 @@ public class AMQPBrokerConnection implements ClientConnectionLifeCycleListener,
    }
 
    /**
-    * Provides an error API for resources of the broker connection that
-    * encounter errors during the normal operation of the resource that
-    * represent a terminal outcome for the connection. The connection
-    * retry counter will be reset to zero for these types of errors as
-    * these indicate a connection interruption that should initiate the
-    * start of a reconnect cycle if reconnection is configured.
+    * Provides an error API for resources of the broker connection that encounter errors during the normal operation of
+    * the resource that represent a terminal outcome for the connection. The connection retry counter will be reset to
+    * zero for these types of errors as these indicate a connection interruption that should initiate the start of a
+    * reconnect cycle if reconnection is configured.
     *
-    * @param error
-    *    The exception that describes the terminal connection error.
+    * @param error The exception that describes the terminal connection error.
     */
    public void runtimeError(Throwable error) {
       error(error, 0);
    }
 
    /**
-    * Provides an error API for resources of the broker connection that
-    * encounter errors during the connection / resource initialization
-    * phase that should constitute a terminal outcome for the connection.
-    * The connection retry counter will be incremented for these types of
-    * errors which can result in eventual termination of reconnect attempts
-    * when the limit is exceeded.
+    * Provides an error API for resources of the broker connection that encounter errors during the connection /
+    * resource initialization phase that should constitute a terminal outcome for the connection. The connection retry
+    * counter will be incremented for these types of errors which can result in eventual termination of reconnect
+    * attempts when the limit is exceeded.
     *
-    * @param error
-    *    The exception that describes the terminal connection error.
+    * @param error The exception that describes the terminal connection error.
     */
    public void connectError(Throwable error) {
       error(error, lastRetryCounter);
@@ -929,11 +1001,11 @@ public class AMQPBrokerConnection implements ClientConnectionLifeCycleListener,
          tunnelCoreMessages = verifyCapabilities(sender.getDesiredCapabilities(), AmqpSupport.CORE_MESSAGE_TUNNELING_SUPPORT) &&
                               verifyOfferedCapabilities(sender, AmqpSupport.CORE_MESSAGE_TUNNELING_SUPPORT);
 
-         return (Consumer) sessionSPI.createSender(senderContext, queueName, null, false);
+         return sessionSPI.createSender(senderContext, queueName, null, false);
       }
 
       @Override
-      public void close() throws Exception {
+      public void close(boolean remoteClose) throws Exception {
 
       }
 
@@ -998,15 +1070,18 @@ public class AMQPBrokerConnection implements ClientConnectionLifeCycleListener,
    }
 
    private void redoConnection() {
-
       // avoiding retro-feeding an error call from the close after anything else that happened.
-      if (protonRemotingConnection != null) {
-         protonRemotingConnection.getAmqpConnection().clearLinkRemoteCloseListeners();
+      final ActiveMQProtonRemotingConnection remotingConnection = this.protonRemotingConnection;
+
+      if (remotingConnection != null) {
+         remotingConnection.getAmqpConnection().clearLinkRemoteCloseListeners();
       }
 
-      if (brokerFederation != null) {
+      final AMQPFederationSource federation = this.brokerFederation;
+
+      if (federation != null) {
          try {
-            brokerFederation.handleConnectionDropped();
+            federation.connectionInterrupted();
          } catch (ActiveMQException e) {
             logger.debug("Broker Federation on connection {} threw an error on stop before connection attempt", getName());
          }
@@ -1076,7 +1151,7 @@ public class AMQPBrokerConnection implements ClientConnectionLifeCycleListener,
       }
 
       public static boolean isApplicable(final String username, final String password) {
-         return username != null && username.length() > 0 && password != null && password.length() > 0;
+         return username != null && !username.isEmpty() && password != null && !password.isEmpty();
       }
    }
 
@@ -1161,10 +1236,10 @@ public class AMQPBrokerConnection implements ClientConnectionLifeCycleListener,
    public static boolean isCoreMessageTunnelingEnabled(AMQPMirrorBrokerConnectionElement configuration) {
       final Object property = configuration.getProperties().get(AmqpSupport.TUNNEL_CORE_MESSAGES);
 
-      if (property instanceof Boolean) {
-         return (Boolean) property;
-      } else if (property instanceof String) {
-         return Boolean.parseBoolean((String) property);
+      if (property instanceof Boolean booleanValue) {
+         return booleanValue;
+      } else if (property instanceof String string) {
+         return Boolean.parseBoolean(string);
       } else {
          return DEFAULT_CORE_MESSAGE_TUNNELING_ENABLED;
       }
