@@ -779,10 +779,6 @@ public class QueueControlImpl extends AbstractControl implements QueueControl {
       }
    }
 
-   /**
-    * @param refs
-    * @return
-    */
    private Map<String, Object>[] convertMessagesToMaps(List<MessageReference> refs) throws ActiveMQException {
       final int attributeSizeLimit = addressSettingsRepository.getMatch(address).getManagementMessageAttributeSizeLimit();
       Map<String, Object>[] messages = new Map[refs.size()];
@@ -885,12 +881,11 @@ public class QueueControlImpl extends AbstractControl implements QueueControl {
    }
 
    /**
-    * this method returns a Map representing the first message.
-    * or null if there's no first message.
-    * @return
-    * @throws Exception
+    * this method returns a Map representing the first message. or null if there's no first message.
+    *
     * @deprecated Use {@link #peekFirstMessage()} instead.
     */
+   @Deprecated
    protected Map<String, Object> getFirstMessage() throws Exception {
       if (AuditLogger.isBaseLoggingEnabled()) {
          AuditLogger.getFirstMessage(queue);
@@ -913,8 +908,8 @@ public class QueueControlImpl extends AbstractControl implements QueueControl {
    }
 
    /**
-    * this method returns a Map representing the first message.
-    * or null if there's no first message.
+    * this method returns a Map representing the first message. or null if there's no first message.
+    *
     * @return A result of {@link Message#toMap()}
     */
    protected Map<String, Object> peekFirstMessage() {
@@ -938,8 +933,8 @@ public class QueueControlImpl extends AbstractControl implements QueueControl {
    }
 
    /**
-    * this method returns a Map representing the first scheduled message.
-    * or null if there's no first message.
+    * this method returns a Map representing the first scheduled message. or null if there's no first message.
+    *
     * @return A result of {@link Message#toMap()}
     */
    protected Map<String, Object> peekFirstScheduledMessage() {
@@ -966,6 +961,7 @@ public class QueueControlImpl extends AbstractControl implements QueueControl {
     * @deprecated Use {@link #peekFirstMessageAsJSON()} instead.
     */
    @Override
+   @Deprecated
    public String getFirstMessageAsJSON() throws Exception {
       if (AuditLogger.isBaseLoggingEnabled()) {
          AuditLogger.getFirstMessageAsJSON(queue);
@@ -978,7 +974,8 @@ public class QueueControlImpl extends AbstractControl implements QueueControl {
 
    /**
     * Uses {@link #peekFirstMessage()} and returns the result as JSON.
-    * @return A {@link Message} instance as a JSON object, or <code>"null"</code> if there's no such message.
+    *
+    * @return A {@link Message} instance as a JSON object, or {@code "null"} if there's no such message
     */
    @Override
    public String peekFirstMessageAsJSON() {
@@ -994,7 +991,8 @@ public class QueueControlImpl extends AbstractControl implements QueueControl {
 
    /**
     * Uses {@link #peekFirstScheduledMessage()} and returns the result as JSON.
-    * @return A {@link Message} instance as a JSON object, or <code>"null"</code> if there's no such message.
+    *
+    * @return A {@link Message} instance as a JSON object, or {@code "null"} if there's no such message
     */
    @Override
    public String peekFirstScheduledMessageAsJSON() {
@@ -1161,7 +1159,7 @@ public class QueueControlImpl extends AbstractControl implements QueueControl {
          if (groupByProperty == null) {
             result.compute(null, (k, v) -> v == null ? 1 : ++v);
          } else {
-            Object value = message.getObjectProperty(groupByProperty);
+            Object value = message.getObjectPropertyForFilter(groupByProperty);
             String valueStr = value == null ? null : value.toString();
             result.compute(valueStr, (k, v) -> v == null ? 1 : ++v);
          }
@@ -1361,6 +1359,32 @@ public class QueueControlImpl extends AbstractControl implements QueueControl {
 
    }
 
+   @Override
+   public boolean copyMessage(final long messageID,
+                              final String targetQueue) throws Exception {
+      // this is a critical task, we need to prevent parallel tasks running
+      try (AutoCloseable lock = server.managementLock()) {
+         if (AuditLogger.isBaseLoggingEnabled()) {
+            AuditLogger.copyMessage(queue, messageID, targetQueue);
+         }
+         checkStarted();
+
+         clearIO();
+         try {
+            Binding binding = server.getPostOffice().getBinding(SimpleString.of(targetQueue));
+
+            if (binding == null) {
+               throw ActiveMQMessageBundle.BUNDLE.noQueueFound(targetQueue);
+            }
+
+            return queue.copyReference(messageID, binding.getAddress(), binding);
+         } finally {
+            blockOnIO();
+         }
+      }
+
+   }
+
    @Override
    public int moveMessages(final String filterStr, final String otherQueueName) throws Exception {
       return moveMessages(filterStr, otherQueueName, false);
@@ -1382,6 +1406,10 @@ public class QueueControlImpl extends AbstractControl implements QueueControl {
                            final int messageCount) throws Exception {
       // this is a critical task, we need to prevent parallel tasks running
       try (AutoCloseable lock = server.managementLock()) {
+         if (this.queue.getName().toString().equals(otherQueueName)) {
+            //doesn't make sense to move messages to itself
+            throw new IllegalArgumentException("Cannot move messages onto itself");
+         }
          if (AuditLogger.isBaseLoggingEnabled()) {
             AuditLogger.moveMessages(queue, flushLimit, filterStr, otherQueueName, rejectDuplicates, messageCount);
          }
@@ -1714,7 +1742,7 @@ public class QueueControlImpl extends AbstractControl implements QueueControl {
             long start = (long) (page - 1) * pageSize;
             long end = Math.min((long) page * pageSize, queue.getMessageCount());
 
-            ArrayList<CompositeData> c = new ArrayList<>();
+            List<CompositeData> c = new ArrayList<>();
             Filter thefilter = FilterImpl.createFilter(filter);
 
             final int attributeSizeLimit = addressSettingsRepository.getMatch(address).getManagementMessageAttributeSizeLimit();
@@ -1775,7 +1803,7 @@ public class QueueControlImpl extends AbstractControl implements QueueControl {
             final int attributeSizeLimit = addressSettings.getManagementMessageAttributeSizeLimit();
             final int limit = addressSettings.getManagementBrowsePageSize();
             int currentPageSize = 0;
-            ArrayList<CompositeData> c = new ArrayList<>();
+            List<CompositeData> c = new ArrayList<>();
             Filter thefilter = FilterImpl.createFilter(filter);
             try (LinkedListIterator<MessageReference> iterator = queue.browserIterator()) {
                try {
@@ -1885,8 +1913,7 @@ public class QueueControlImpl extends AbstractControl implements QueueControl {
 
             for (Map.Entry<SimpleString, Consumer> group : groups.entrySet()) {
 
-               if (group.getValue() instanceof ServerConsumer) {
-                  ServerConsumer serverConsumer = (ServerConsumer) group.getValue();
+               if (group.getValue() instanceof ServerConsumer serverConsumer) {
 
                   JsonObjectBuilder obj = JsonLoader.createObjectBuilder().add("groupID", group.getKey().toString()).add("consumerID", serverConsumer.getID()).add("connectionID", serverConsumer.getConnectionID().toString()).add("sessionID", serverConsumer.getSessionID()).add("browseOnly", serverConsumer.isBrowseOnly()).add("creationTime", serverConsumer.getCreationTime());
 
@@ -1932,8 +1959,7 @@ public class QueueControlImpl extends AbstractControl implements QueueControl {
 
          for (Consumer consumer : consumers) {
 
-            if (consumer instanceof ServerConsumer) {
-               ServerConsumer serverConsumer = (ServerConsumer) consumer;
+            if (consumer instanceof ServerConsumer serverConsumer) {
                JsonObjectBuilder obj = JsonLoader.createObjectBuilder()
                        .add(ConsumerField.ID.getAlternativeName(), serverConsumer.getID())
                        .add(ConsumerField.SEQUENTIAL_ID.getAlternativeName(), serverConsumer.getSequentialID())
@@ -2121,8 +2147,7 @@ public class QueueControlImpl extends AbstractControl implements QueueControl {
                   List<TransactionOperation> allOperations = transaction.getAllOperations();
 
                   for (TransactionOperation operation : allOperations) {
-                     if (operation instanceof RefsOperation) {
-                        RefsOperation refsOperation = (RefsOperation) operation;
+                     if (operation instanceof RefsOperation refsOperation) {
                         List<MessageReference> references = refsOperation.getReferencesToAcknowledge();
                         for (MessageReference reference : references) {
                            if (reference != null && reference.getQueue().getName().equals(queue.getName())) {
