@@ -25,16 +25,14 @@ import java.util.HashMap;
 import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
+import java.util.Set;
 import java.util.concurrent.CountDownLatch;
 import java.util.concurrent.RejectedExecutionException;
 import java.util.concurrent.ScheduledExecutorService;
-import java.util.concurrent.Semaphore;
 import java.util.concurrent.TimeUnit;
 
 import org.apache.activemq.artemis.api.core.ActiveMQBuffer;
 import org.apache.activemq.artemis.api.core.ActiveMQException;
-import org.apache.activemq.artemis.api.core.ActiveMQIllegalStateException;
-import org.apache.activemq.artemis.api.core.ActiveMQInternalErrorException;
 import org.apache.activemq.artemis.api.core.Message;
 import org.apache.activemq.artemis.api.core.Pair;
 import org.apache.activemq.artemis.api.core.SimpleString;
@@ -56,9 +54,8 @@ import org.apache.activemq.artemis.core.paging.PagingManager;
 import org.apache.activemq.artemis.core.paging.PagingStore;
 import org.apache.activemq.artemis.core.persistence.OperationContext;
 import org.apache.activemq.artemis.core.persistence.impl.journal.codec.LargeMessagePersister;
-import org.apache.activemq.artemis.core.persistence.impl.journal.codec.PendingLargeMessageEncoding;
 import org.apache.activemq.artemis.core.persistence.impl.journal.codec.RefEncoding;
-import org.apache.activemq.artemis.core.protocol.core.impl.wireformat.ReplicationLiveIsStoppingMessage;
+import org.apache.activemq.artemis.core.protocol.core.impl.wireformat.ReplicationPrimaryIsStoppingMessage;
 import org.apache.activemq.artemis.core.replication.ReplicatedJournal;
 import org.apache.activemq.artemis.core.replication.ReplicationManager;
 import org.apache.activemq.artemis.core.server.ActiveMQMessageBundle;
@@ -70,11 +67,13 @@ import org.apache.activemq.artemis.journal.ActiveMQJournalBundle;
 import org.apache.activemq.artemis.utils.ArtemisCloseable;
 import org.apache.activemq.artemis.utils.ExecutorFactory;
 import org.apache.activemq.artemis.utils.critical.CriticalAnalyzer;
-import org.jboss.logging.Logger;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
+import java.lang.invoke.MethodHandles;
 
 public class JournalStorageManager extends AbstractJournalStorageManager {
 
-   private static final Logger logger = Logger.getLogger(JournalStorageManager.class);
+   private static final Logger logger = LoggerFactory.getLogger(MethodHandles.lookup().lookupClass());
    public static final String ACTIVEMQ_DATA = "activemq-data";
 
    protected SequentialFileFactory journalFF;
@@ -183,20 +182,14 @@ public class JournalStorageManager extends AbstractJournalStorageManager {
       largeMessagesDirectory = config.getLargeMessagesDirectory();
 
       largeMessagesFactory = new NIOSequentialFileFactory(config.getLargeMessagesLocation(), false, criticalErrorListener, 1);
-
-      // it doesn't make sense to limit paging concurrency < 0
-      if (config.getPageMaxConcurrentIO() >= 0) {
-         pageMaxConcurrentIO = new Semaphore(config.getPageMaxConcurrentIO());
-      } else {
-         pageMaxConcurrentIO = null;
-      }
    }
 
    /**
     * We need to correct the file size if its not a multiple of the alignement
-    * @param fileSize : the configured file size.
+    *
+    * @param fileSize  : the configured file size.
     * @param alignment : the alignment.
-    * @return the fixed file size.
+    * @return the fixed file size
     */
    protected int fixJournalFileSize(int fileSize, int alignment) {
       int size = fileSize;
@@ -224,10 +217,14 @@ public class JournalStorageManager extends AbstractJournalStorageManager {
    // Life Cycle Handlers
    @Override
    protected void beforeStart() throws Exception {
+      createDirectories();
+      cleanupIncompleteFiles();
+   }
+
+   protected void createDirectories() {
       checkAndCreateDir(config.getBindingsLocation(), config.isCreateBindingsDir());
       checkAndCreateDir(config.getJournalLocation(), config.isCreateJournalDir());
       checkAndCreateDir(config.getLargeMessagesLocation(), config.isCreateJournalDir());
-      cleanupIncompleteFiles();
    }
 
    @Override
@@ -242,8 +239,9 @@ public class JournalStorageManager extends AbstractJournalStorageManager {
       stop(false, true);
    }
 
+   @Override
    public boolean isReplicated() {
-      return replicator != null;
+      return replicator != null && replicator.isStarted();
    }
 
    private void cleanupIncompleteFiles() throws Exception {
@@ -280,12 +278,7 @@ public class JournalStorageManager extends AbstractJournalStorageManager {
 
       final CountDownLatch latch = new CountDownLatch(1);
       try {
-         executor.execute(new Runnable() {
-            @Override
-            public void run() {
-               latch.countDown();
-            }
-         });
+         executor.execute(latch::countDown);
 
          latch.await(30, TimeUnit.SECONDS);
       } catch (RejectedExecutionException ignored) {
@@ -297,12 +290,12 @@ public class JournalStorageManager extends AbstractJournalStorageManager {
          try {
 
             // We cache the variable as the replicator could be changed between here and the time we call stop
-            // since sendLiveIsStopping may issue a close back from the channel
+            // since sendPrimaryIsStopping may issue a close back from the channel
             // and we want to ensure a stop here just in case
             ReplicationManager replicatorInUse = replicator;
             if (replicatorInUse != null) {
                if (sendFailover) {
-                  final OperationContext token = replicator.sendLiveIsStopping(ReplicationLiveIsStoppingMessage.LiveStopping.FAIL_OVER);
+                  final OperationContext token = replicator.sendPrimaryIsStopping(ReplicationPrimaryIsStoppingMessage.PrimaryStopping.FAIL_OVER);
                   if (token != null) {
                      try {
                         token.waitCompletion(5000);
@@ -341,12 +334,11 @@ public class JournalStorageManager extends AbstractJournalStorageManager {
             try {
                msg.delete();
             } catch (Exception e) {
-               ActiveMQServerLogger.LOGGER.journalErrorDeletingMessage(e, messageId);
+               ActiveMQServerLogger.LOGGER.journalErrorDeletingMessage(messageId, e);
             }
             if (replicator != null) {
                replicator.largeMessageDelete(messageId, JournalStorageManager.this);
             }
-            confirmLargeMessage(largeServerMessage);
          });
          largeMessagesToDelete.clear();
       } finally {
@@ -355,13 +347,8 @@ public class JournalStorageManager extends AbstractJournalStorageManager {
    }
 
    @Override
-   /**
-    * @param buff
-    * @return
-    * @throws Exception
-    */
    protected LargeServerMessage parseLargeMessage(final ActiveMQBuffer buff) throws Exception {
-      LargeServerMessage largeMessage = createLargeMessage();
+      LargeServerMessage largeMessage = createCoreLargeMessage();
 
       LargeMessagePersister.getInstance().decode(buff, largeMessage, null);
 
@@ -388,7 +375,7 @@ public class JournalStorageManager extends AbstractJournalStorageManager {
    }
 
    @Override
-   public void pageClosed(final SimpleString storeName, final int pageNumber) {
+   public void pageClosed(final SimpleString storeName, final long pageNumber) {
       if (isReplicated()) {
          try (ArtemisCloseable lock = closeableReadLock()) {
             if (isReplicated())
@@ -398,7 +385,7 @@ public class JournalStorageManager extends AbstractJournalStorageManager {
    }
 
    @Override
-   public void pageDeleted(final SimpleString storeName, final int pageNumber) {
+   public void pageDeleted(final SimpleString storeName, final long pageNumber) {
       if (isReplicated()) {
          try (ArtemisCloseable lock = closeableReadLock()) {
             if (isReplicated())
@@ -408,7 +395,7 @@ public class JournalStorageManager extends AbstractJournalStorageManager {
    }
 
    @Override
-   public void pageWrite(final PagedMessage message, final int pageNumber) {
+   public void pageWrite(final SimpleString address, final PagedMessage message, final long pageNumber, boolean storageUp, boolean originallyReplicated) {
       if (messageJournal.isHistory()) {
          try (ArtemisCloseable lock = closeableReadLock()) {
 
@@ -426,16 +413,28 @@ public class JournalStorageManager extends AbstractJournalStorageManager {
             logger.warn(e.getMessage(), e);
          }
       }
-      if (isReplicated()) {
-         // Note: (https://issues.jboss.org/browse/HORNETQ-1059)
-         // We have to replicate durable and non-durable messages on paging
-         // since acknowledgments are written using the page-position.
-         // Say you are sending durable and non-durable messages to a page
-         // The ACKs would be done to wrong positions, and the backup would be a mess
 
+      if (isReplicated()) {
          try (ArtemisCloseable lock = closeableReadLock()) {
-            if (isReplicated())
-               replicator.pageWrite(message, pageNumber);
+            if (isReplicated()) {
+               replicator.pageWrite(address, message, pageNumber, storageUp);
+            } else {
+               if (originallyReplicated) {
+                  // this is a case where we originally contemplated as replicated, so we have to discount it in case it is not any more
+                  OperationContext context = OperationContextImpl.getContext();
+                  if (context != null) {
+                     context.replicationDone();
+                  }
+               }
+            }
+         }
+      } else {
+         if (originallyReplicated) {
+            // this is a case where we originally contemplated as replicated, so we have to discount it in case it is not any more
+            OperationContext context = OperationContextImpl.getContext();
+            if (context != null) {
+               context.replicationDone();
+            }
          }
       }
    }
@@ -450,15 +449,6 @@ public class JournalStorageManager extends AbstractJournalStorageManager {
       journalFF.releaseBuffer(buffer);
    }
 
-   public long storePendingLargeMessage(final long messageID) throws Exception {
-      try (ArtemisCloseable lock = closeableReadLock()) {
-         long recordID = generateID();
-         messageJournal.appendAddRecord(recordID, JournalRecordIds.ADD_LARGE_MESSAGE_PENDING, new PendingLargeMessageEncoding(messageID), true, getContext(true));
-
-         return recordID;
-      }
-   }
-
    @Override
    public void largeMessageClosed(LargeServerMessage largeServerMessage) throws ActiveMQException {
       try (ArtemisCloseable lock = closeableReadLock()) {
@@ -470,19 +460,6 @@ public class JournalStorageManager extends AbstractJournalStorageManager {
 
    @Override
    public void deleteLargeMessageBody(final LargeServerMessage largeServerMessage) throws ActiveMQException {
-      synchronized (largeServerMessage) {
-         if (!largeServerMessage.hasPendingRecord()) {
-            try {
-               // The delete file happens asynchronously
-               // And the client won't be waiting for the actual file to be deleted.
-               // We set a temporary record (short lived) on the journal
-               // to avoid a situation where the server is restarted and pending large message stays on forever
-               largeServerMessage.setPendingRecordID(storePendingLargeMessage(largeServerMessage.toMessage().getMessageID()));
-            } catch (Exception e) {
-               throw new ActiveMQInternalErrorException(e.getMessage(), e);
-            }
-         }
-      }
       final SequentialFile file = largeServerMessage.getAppendFile();
       if (file == null) {
          return;
@@ -496,24 +473,17 @@ public class JournalStorageManager extends AbstractJournalStorageManager {
             }
          }
       }
-      Runnable deleteAction = new Runnable() {
-         @Override
-         public void run() {
-            try {
-               try (ArtemisCloseable lock = closeableReadLock()) {
-                  if (replicator != null) {
-                     replicator.largeMessageDelete(largeServerMessage.toMessage().getMessageID(), JournalStorageManager.this);
-                  }
-                  file.delete();
-
-                  // The confirm could only be done after the actual delete is done
-                  confirmLargeMessage(largeServerMessage);
+      Runnable deleteAction = () -> {
+         try {
+            try (ArtemisCloseable lock = closeableReadLock()) {
+               if (replicator != null) {
+                  replicator.largeMessageDelete(largeServerMessage.toMessage().getMessageID(), JournalStorageManager.this);
                }
-            } catch (Exception e) {
-               ActiveMQServerLogger.LOGGER.journalErrorDeletingMessage(e, largeServerMessage.toMessage().getMessageID());
+               file.delete();
             }
+         } catch (Exception e) {
+            ActiveMQServerLogger.LOGGER.journalErrorDeletingMessage(largeServerMessage.toMessage().getMessageID(), e);
          }
-
       };
 
       getContext(true).executeOnCompletion(new IOCallback() {
@@ -534,60 +504,48 @@ public class JournalStorageManager extends AbstractJournalStorageManager {
    }
 
    @Override
-   public LargeServerMessage createLargeMessage() {
+   public LargeServerMessage createCoreLargeMessage() {
       return new LargeServerMessageImpl(this);
    }
 
    @Override
-   public LargeServerMessage createLargeMessage(final long id, final Message message) throws Exception {
+   public LargeServerMessage createCoreLargeMessage(final long id, final Message message) throws Exception {
+      if (logger.isTraceEnabled()) {
+         logger.trace("Initializing large message {}", id, new Exception("trace"));
+      }
       try (ArtemisCloseable lock = closeableReadLock()) {
          if (isReplicated()) {
             replicator.largeMessageBegin(id);
          }
 
-         LargeServerMessageImpl largeMessage = (LargeServerMessageImpl) createLargeMessage();
+         LargeServerMessageImpl largeMessage = (LargeServerMessageImpl) createCoreLargeMessage();
 
          largeMessage.moveHeadersAndProperties(message);
 
-         return largeMessageCreated(id, largeMessage);
+         return onLargeMessageCreate(id, largeMessage);
       }
    }
 
    @Override
-   public LargeServerMessage largeMessageCreated(long id, LargeServerMessage largeMessage) throws Exception {
+   public LargeServerMessage onLargeMessageCreate(long id, LargeServerMessage largeMessage) throws Exception {
       largeMessage.setMessageID(id);
 
       // Check durable large massage size before to allocate resources if it can't be stored
       if (largeMessage.toMessage().isDurable()) {
          final long maxRecordSize = getMaxRecordSize();
-         if (largeMessage instanceof LargeServerMessageImpl) {
-            // the following check only applies to Core
-            LargeServerMessageImpl coreLarge = (LargeServerMessageImpl)largeMessage;
-            final int messageEncodeSize = coreLarge.getEncodeSize();
+         if (largeMessage instanceof LargeServerMessageImpl largeServerMessage) {
+            final int messageEncodeSize = largeServerMessage.getEncodeSize();
 
             if (messageEncodeSize > maxRecordSize) {
                ActiveMQServerLogger.LOGGER.messageWithHeaderTooLarge(largeMessage.getMessageID(), logger.getName());
 
-               if (logger.isDebugEnabled()) {
-                  logger.debug("Message header too large for " + largeMessage);
-               }
+               logger.debug("Message header too large for {}", largeMessage);
 
                throw ActiveMQJournalBundle.BUNDLE.recordLargerThanStoreMax(messageEncodeSize, maxRecordSize);
             }
          }
       }
 
-      // We do this here to avoid a case where the replication gets a list without this file
-      // to avoid a race
-      largeMessage.validateFile();
-
-      if (largeMessage.toMessage().isDurable()) {
-         // We store a marker on the journal that the large file is pending
-         long pendingRecordID = storePendingLargeMessage(id);
-
-         largeMessage.setPendingRecordID(pendingRecordID);
-      }
-
       return largeMessage;
    }
 
@@ -623,6 +581,10 @@ public class JournalStorageManager extends AbstractJournalStorageManager {
       return datafiles;
    }
 
+   void setReplicator(ReplicationManager replicator) {
+      this.replicator = replicator;
+   }
+
    @Override
    public void startReplication(ReplicationManager replicationManager,
                                 PagingManager pagingManager,
@@ -634,7 +596,7 @@ public class JournalStorageManager extends AbstractJournalStorageManager {
       }
       assert replicationManager != null;
 
-      if (!(messageJournal instanceof JournalImpl) || !(bindingsJournal instanceof JournalImpl)) {
+      if (!(originalMessageJournal instanceof JournalImpl) || !(originalBindingsJournal instanceof JournalImpl)) {
          throw ActiveMQMessageBundle.BUNDLE.notJournalImpl();
       }
 
@@ -646,7 +608,7 @@ public class JournalStorageManager extends AbstractJournalStorageManager {
       JournalFile[] messageFiles = null;
       JournalFile[] bindingsFiles = null;
 
-      // We get a picture of the current sitaution on the large messages
+      // We get a picture of the current situation on the large messages
       // and we send the current messages while more state is coming
       Map<Long, Pair<String, Long>> pendingLargeMessages = null;
 
@@ -659,17 +621,13 @@ public class JournalStorageManager extends AbstractJournalStorageManager {
          pagingManager.lock();
          storageManagerLock.writeLock().lock();
          try {
-            if (isReplicated())
-               throw new ActiveMQIllegalStateException("already replicating");
+            if (isReplicated()) {
+               throw ActiveMQMessageBundle.BUNDLE.alreadyReplicating(replicator.isStarted());
+            }
             replicator = replicationManager;
 
-            if (!((JournalImpl) originalMessageJournal).flushAppendExecutor(10, TimeUnit.SECONDS)) {
-               throw new Exception("Live message journal is busy");
-            }
-
-            if (!((JournalImpl) originalBindingsJournal).flushAppendExecutor(10, TimeUnit.SECONDS)) {
-               throw new Exception("Live bindings journal is busy");
-            }
+            ((JournalImpl) originalMessageJournal).flushAppendExecutor(10, TimeUnit.SECONDS);
+            ((JournalImpl) originalBindingsJournal).flushAppendExecutor(10, TimeUnit.SECONDS);
 
             // Establishes lock
             originalMessageJournal.synchronizationLock();
@@ -750,17 +708,15 @@ public class JournalStorageManager extends AbstractJournalStorageManager {
       }
    }
 
-   /**
-    * @param pagingManager
-    * @return
-    * @throws Exception
-    */
    private Map<SimpleString, Collection<Integer>> getPageInformationForSync(PagingManager pagingManager) throws Exception {
       Map<SimpleString, Collection<Integer>> info = new HashMap<>();
       for (SimpleString storeName : pagingManager.getStoreNames()) {
          PagingStore store = pagingManager.getPageStore(storeName);
-         info.put(storeName, store.getCurrentIds());
-         store.forceAnotherPage();
+         Collection<Integer> ids = store.getCurrentIds();
+         info.put(storeName, ids);
+         if (!ids.isEmpty()) {
+            store.forceAnotherPage();
+         }
       }
       return info;
    }
@@ -768,7 +724,7 @@ public class JournalStorageManager extends AbstractJournalStorageManager {
    private void checkAndCreateDir(final File dir, final boolean create) {
       if (!dir.exists()) {
          if (create) {
-            if (!dir.mkdirs()) {
+            if (!dir.mkdirs() && !dir.exists()) {
                throw new IllegalStateException("Failed to create directory " + dir);
             }
          } else {
@@ -782,10 +738,8 @@ public class JournalStorageManager extends AbstractJournalStorageManager {
     * <p>
     * Collects a list of existing large messages and their current size, passing re.
     * <p>
-    * So we know how much of a given message to sync with the backup. Further data appends to the
-    * messages will be replicated normally.
-    *
-    * @throws Exception
+    * So we know how much of a given message to sync with the backup. Further data appends to the messages will be
+    * replicated normally.
     */
    private Map<Long, Pair<String, Long>> recoverPendingLargeMessages() throws Exception {
 
@@ -805,10 +759,14 @@ public class JournalStorageManager extends AbstractJournalStorageManager {
       return largeMessages;
    }
 
-   /**
-    * @param pageFilesToSync
-    * @throws Exception
-    */
+   @Override
+   public void recoverLargeMessagesOnFolder(Set<Long> storedLargeMessages) throws Exception {
+      List<String> filenames = largeMessagesFactory.listFiles("msg");
+      filenames.forEach(f -> {
+         storedLargeMessages.add(getLargeMessageIdFromFilename(f));
+      });
+   }
+
    private void sendPagesToBackup(Map<SimpleString, Collection<Integer>> pageFilesToSync,
                                   PagingManager manager) throws Exception {
       for (Map.Entry<SimpleString, Collection<Integer>> entry : pageFilesToSync.entrySet()) {
@@ -857,7 +815,7 @@ public class JournalStorageManager extends AbstractJournalStorageManager {
    }
 
    @Override
-   public final void addBytesToLargeMessage(final SequentialFile file,
+   public void addBytesToLargeMessage(final SequentialFile file,
                                             final long messageId,
                                             final ActiveMQBuffer bytes) throws Exception {
       try (ArtemisCloseable lock = closeableReadLock()) {
@@ -886,15 +844,15 @@ public class JournalStorageManager extends AbstractJournalStorageManager {
    private void historyBody(long messageId, EncodingSupport partialBuffer) {
 
       try {
-         messageJournal.appendAddEvent(messageId, JournalRecordIds.ADD_MESSAGE_BODY, EncoderPersister.getInstance(), partialBuffer, true, null);
+         messageJournal.appendAddEvent(messageId, JournalRecordIds.ADD_MESSAGE_BODY, EncoderPersister.getInstance(), partialBuffer, false, null);
       } catch (Exception e) {
-         logger.warn("Error processing history large message body for " + messageId + " - " + e.getMessage(), e);
+         logger.warn("Error processing history large message body for {}", messageId, e);
       }
 
    }
 
    @Override
-   public final void addBytesToLargeMessage(final SequentialFile file,
+   public void addBytesToLargeMessage(final SequentialFile file,
                                             final long messageId,
                                             final byte[] bytes) throws Exception {
       try (ArtemisCloseable lock = closeableReadLock()) {
@@ -925,4 +883,13 @@ public class JournalStorageManager extends AbstractJournalStorageManager {
          monitor.addStore(bindingsFF.getDirectory());
       }
    }
+
+   @Override
+   public int getAllowedPageSize(int pageSize)  {
+      if (config.getStoreConfiguration() == null) {
+         return pageSize;
+      }
+      return config.getStoreConfiguration().getAllowedPageSize(pageSize);
+   }
+
 }
