@@ -95,8 +95,8 @@ import org.apache.http.impl.client.HttpClientBuilder;
 import org.apache.http.impl.conn.DefaultRoutePlanner;
 import org.apache.http.protocol.HttpContext;
 import org.apache.http.ssl.SSLContextBuilder;
-import org.eclipse.jetty.ee8.webapp.WebAppContext;
-import org.eclipse.jetty.ee8.webapp.WebInfConfiguration;
+import org.eclipse.jetty.ee9.webapp.WebAppContext;
+import org.eclipse.jetty.ee9.webapp.WebInfConfiguration;
 import org.eclipse.jetty.util.ssl.SslContextFactory;
 import org.eclipse.jetty.util.thread.ThreadPool;
 import org.junit.jupiter.api.AfterEach;
@@ -106,6 +106,7 @@ import org.junit.jupiter.api.io.TempDir;
 
 import static org.junit.jupiter.api.Assertions.assertEquals;
 import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertNotEquals;
 import static org.junit.jupiter.api.Assertions.assertNotNull;
 import static org.junit.jupiter.api.Assertions.assertNull;
 import static org.junit.jupiter.api.Assertions.assertTrue;
@@ -185,7 +186,7 @@ public class WebServerComponentTest extends ArtemisTestCase {
       if (useCustomizer) {
          assertEquals(1, TestCustomizer.count);
       }
-      assertEquals(clientHandler.body.toString(), "12345");
+      assertEquals("12345", clientHandler.body.toString());
       assertNull(clientHandler.serverHeader);
       // Wait for the server to close the connection.
       ch.close();
@@ -809,7 +810,7 @@ public class WebServerComponentTest extends ArtemisTestCase {
       Thread.sleep(5);
       webServerComponent.start();
       assertTrue(webServerComponent.isStarted());
-      assertFalse(originalLastModified == Files.getLastModifiedTime(Paths.get(ctxt.getTempDirectory().getAbsolutePath())).toMillis());
+      assertNotEquals(originalLastModified, Files.getLastModifiedTime(Paths.get(ctxt.getTempDirectory().getAbsolutePath())).toMillis());
       webServerComponent.stop(true);
       assertFalse(webServerComponent.isStarted());
       assertFalse(Files.exists(Paths.get(ctxt.getTempDirectory().getAbsolutePath())), ctxt.getTempDirectory().getAbsolutePath() + " exists!");
@@ -831,8 +832,8 @@ public class WebServerComponentTest extends ArtemisTestCase {
       webServerComponent.start();
 
       File tmpDir = ctxt.getTempDirectory();
-      assertTrue(tmpDir.getParentFile().listFiles().length == 1);
-      assertEquals(tmpDir.getName(), warName);
+      assertEquals(1, tmpDir.getParentFile().listFiles().length);
+      assertEquals(warName, tmpDir.getName());
       assertTrue(webServerComponent.isStarted());
 
       webServerComponent.stop(true);
@@ -1022,11 +1023,9 @@ public class WebServerComponentTest extends ArtemisTestCase {
 
       @Override
       public void channelRead0(ChannelHandlerContext ctx, HttpObject msg) {
-         if (msg instanceof HttpResponse) {
-            HttpResponse response = (HttpResponse) msg;
+         if (msg instanceof HttpResponse response) {
             serverHeader = response.headers().get("Server");
-         } else if (msg instanceof HttpContent) {
-            HttpContent content = (HttpContent) msg;
+         } else if (msg instanceof HttpContent content) {
             body.append(content.content().toString(CharsetUtil.UTF_8));
             if (msg instanceof LastHttpContent) {
                latch.countDown();
