@@ -16,8 +16,10 @@
  */
 package org.apache.activemq.artemis.tests.integration.amqp;
 
+import static org.junit.jupiter.api.Assertions.assertArrayEquals;
 import static org.junit.jupiter.api.Assertions.assertEquals;
 import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertInstanceOf;
 import static org.junit.jupiter.api.Assertions.assertNull;
 import static org.junit.jupiter.api.Assertions.assertNotNull;
 import static org.junit.jupiter.api.Assertions.assertTrue;
@@ -62,7 +64,7 @@ import org.apache.activemq.artemis.tests.extensions.parameterized.Parameter;
 import org.apache.activemq.artemis.tests.extensions.parameterized.ParameterizedTestExtension;
 import org.apache.activemq.artemis.tests.extensions.parameterized.Parameters;
 import org.apache.activemq.artemis.tests.util.CFUtil;
-import org.apache.activemq.artemis.tests.util.RandomUtil;
+import org.apache.activemq.artemis.utils.RandomUtil;
 import org.apache.activemq.artemis.tests.util.Wait;
 import org.apache.activemq.artemis.utils.ByteUtil;
 import org.apache.activemq.transport.amqp.client.AmqpClient;
@@ -220,7 +222,7 @@ public class AmqpLargeMessageTest extends AmqpClientTestSupport {
          AmqpSender sender = session.createSender(testQueueName);
          AmqpMessage message = createAmqpMessage((byte) 'A', payload);
 
-         message.setApplicationProperty("IntProperty", (Integer) 42);
+         message.setApplicationProperty("IntProperty", 42);
          message.setDurable(true);
          message.setMessageAnnotation(annotation, embeddedMap);
          sender.send(message);
@@ -277,7 +279,7 @@ public class AmqpLargeMessageTest extends AmqpClientTestSupport {
 
       for (int i = 0; i < nMsgs; ++i) {
          AmqpMessage message = createAmqpMessage((byte) 'A', payload);
-         message.setApplicationProperty("i", (Integer) i);
+         message.setApplicationProperty("i", i);
          message.setDurable(true);
          sender.send(message);
       }
@@ -324,9 +326,8 @@ public class AmqpLargeMessageTest extends AmqpClientTestSupport {
             AmqpMessage message = receiver.receive(5, TimeUnit.SECONDS);
             assertNotNull(message, "failed at " + i);
             MessageImpl wrapped = (MessageImpl) message.getWrappedMessage();
-            if (wrapped.getBody() instanceof Data) {
+            if (wrapped.getBody() instanceof Data data) {
                // converters can change this to AmqValue
-               Data data = (Data) wrapped.getBody();
                logger.debug("received : message: {}", data.getValue().getLength());
                assertEquals(payload, data.getValue().getLength());
             }
@@ -361,7 +362,7 @@ public class AmqpLargeMessageTest extends AmqpClientTestSupport {
          AmqpSender sender = session.createSender(testQueueName);
          AmqpMessage message = createAmqpMessage((byte) 'A', payload);
 
-         message.setApplicationProperty("IntProperty", (Integer) 42);
+         message.setApplicationProperty("IntProperty", 42);
          message.setDurable(true);
          message.setMessageAnnotation(annotation.toString(), embeddedMap);
          sender.send(message);
@@ -380,8 +381,7 @@ public class AmqpLargeMessageTest extends AmqpClientTestSupport {
          AmqpMessage message = receiver.receive(5, TimeUnit.SECONDS);
          assertNotNull(message, "Failed to read message with embedded map in annotations");
          MessageImpl wrapped = (MessageImpl) message.getWrappedMessage();
-         if (wrapped.getBody() instanceof Data) {
-            Data data = (Data) wrapped.getBody();
+         if (wrapped.getBody() instanceof Data data) {
             logger.debug("received : message: {}", data.getValue().getLength());
             assertEquals(payload, data.getValue().getLength());
          }
@@ -521,18 +521,14 @@ public class AmqpLargeMessageTest extends AmqpClientTestSupport {
          AmqpSender sender = session.createSender(testQueueName);
 
          AmqpMessage message = createAmqpMessage((byte) 'A', expectedSize);
-         StringBuffer buffer = new StringBuffer();
-         for (int i = 0; i < strLength; i++) {
-            buffer.append(" ");
-         }
-         message.setApplicationProperty("str", buffer.toString());
+         message.setApplicationProperty("str", " ".repeat(strLength));
          message.setDurable(true);
 
          try {
             sender.send(message);
             fail();
          } catch (IOException e) {
-            assertTrue(e.getCause() instanceof JMSException);
+            assertInstanceOf(JMSException.class, e.getCause());
             assertTrue(e.getMessage().contains("AMQ149005"));
          }
 
@@ -555,19 +551,11 @@ public class AmqpLargeMessageTest extends AmqpClientTestSupport {
    }
 
    private void testLargeHeaderTX(boolean largeBody) throws Exception {
-      String testQueueName = RandomUtil.randomString();
+      String testQueueName = RandomUtil.randomUUIDString();
       server.createQueue(QueueConfiguration.of(testQueueName).setRoutingType(RoutingType.ANYCAST));
       ConnectionFactory cf = CFUtil.createConnectionFactory("AMQP", "tcp://localhost:5672");
 
-      String largeString;
-      {
-         StringBuffer buffer = new StringBuffer();
-         while (buffer.length() < 1024 * 1024) {
-            buffer.append("This is a large string ");
-         }
-         largeString = buffer.toString();
-      }
-
+      String largeString = RandomUtil.randomAlphaNumericString(1024 * 1024);
       String smallString = "small string";
 
       String body = largeBody ? largeString : smallString;
@@ -682,7 +670,7 @@ public class AmqpLargeMessageTest extends AmqpClientTestSupport {
          logger.debug("Calling receive");
          Message received = consumer.receive();
          assertNotNull(received);
-         assertTrue(received instanceof BytesMessage);
+         assertInstanceOf(BytesMessage.class, received);
          BytesMessage bytesMessage = (BytesMessage) received;
          assertNotNull(bytesMessage);
          endTime = System.currentTimeMillis();
@@ -690,7 +678,7 @@ public class AmqpLargeMessageTest extends AmqpClientTestSupport {
          logger.debug("Returned from receive after {} ms", endTime - startTime);
          byte[] bytesReceived = new byte[expectedSize];
          assertEquals(expectedSize, bytesMessage.readBytes(bytesReceived, expectedSize));
-         assertTrue(Arrays.equals(payload, bytesReceived));
+         assertArrayEquals(payload, bytesReceived);
          connection.close();
       }
    }
@@ -733,7 +721,7 @@ public class AmqpLargeMessageTest extends AmqpClientTestSupport {
          AmqpReceiver receiver = session.createReceiver(testQueueName);
          receiver.flow(numMsgs);
 
-         ArrayList<AmqpMessage> messages = new ArrayList<>();
+         List<AmqpMessage> messages = new ArrayList<>();
          for (int i = 0; i < numMsgs; ++i) {
             AmqpMessage message = receiver.receive(5, TimeUnit.SECONDS);
             assertNotNull(message, "failed at " + i);
@@ -823,8 +811,8 @@ public class AmqpLargeMessageTest extends AmqpClientTestSupport {
          receiverA.flow(numMsgs / 2, true);
          receiverB.flow(numMsgs / 2);
 
-         ArrayList<AmqpMessage> messagesA = new ArrayList<>();
-         ArrayList<AmqpMessage> messagesB = new ArrayList<>();
+         List<AmqpMessage> messagesA = new ArrayList<>();
+         List<AmqpMessage> messagesB = new ArrayList<>();
 
          long timeout = 6000;
          long start = System.nanoTime();
@@ -890,7 +878,7 @@ public class AmqpLargeMessageTest extends AmqpClientTestSupport {
       Section body = message.getWrappedMessage().getBody();
       assertNotNull(body, "No message body for msg " + msgNum);
 
-      assertTrue(body instanceof Data, "Unexpected message body type for msg " + body.getClass());
+      assertInstanceOf(Data.class, body, "Unexpected message body type for msg " + body.getClass());
       assertEquals(new Binary(expectedPayload, 0, expectedPayload.length), ((Data) body).getValue(), "Unexpected body content for msg");
    }
 
@@ -919,9 +907,9 @@ public class AmqpLargeMessageTest extends AmqpClientTestSupport {
          assertNotNull(received, "failed to read large AMQP message");
          MessageImpl wrapped = (MessageImpl) received.getWrappedMessage();
 
-         assertTrue(wrapped.getBody() instanceof AmqpValue);
+         assertInstanceOf(AmqpValue.class, wrapped.getBody());
          AmqpValue body = (AmqpValue) wrapped.getBody();
-         assertTrue(body.getValue() instanceof Binary);
+         assertInstanceOf(Binary.class, body.getValue());
          Binary payload = (Binary) body.getValue();
          assertEquals(0, payload.getLength());
 
@@ -957,10 +945,10 @@ public class AmqpLargeMessageTest extends AmqpClientTestSupport {
          assertNotNull(received, "failed to read large AMQP message");
          MessageImpl wrapped = (MessageImpl) received.getWrappedMessage();
 
-         assertTrue(wrapped.getBody() instanceof Data);
+         assertInstanceOf(Data.class, wrapped.getBody());
          Data body = (Data) wrapped.getBody();
-         assertTrue(body.getValue() instanceof Binary);
-         Binary payload = (Binary) body.getValue();
+         assertInstanceOf(Binary.class, body.getValue());
+         Binary payload = body.getValue();
          assertEquals(0, payload.getLength());
 
          received.accept();
@@ -999,10 +987,10 @@ public class AmqpLargeMessageTest extends AmqpClientTestSupport {
          assertNotNull(received, "failed to read large AMQP message");
          MessageImpl wrapped = (MessageImpl) received.getWrappedMessage();
 
-         assertTrue(wrapped.getBody() instanceof Data);
+         assertInstanceOf(Data.class, wrapped.getBody());
          Data body = (Data) wrapped.getBody();
-         assertTrue(body.getValue() instanceof Binary);
-         Binary payload = (Binary) body.getValue();
+         assertInstanceOf(Binary.class, body.getValue());
+         Binary payload = body.getValue();
          String reconstitutedString = new String(
             payload.getArray(), payload.getArrayOffset(), payload.getLength(), StandardCharsets.UTF_8);
 
@@ -1046,9 +1034,9 @@ public class AmqpLargeMessageTest extends AmqpClientTestSupport {
          assertNotNull(received, "failed to read large AMQP message");
          MessageImpl wrapped = (MessageImpl) received.getWrappedMessage();
 
-         assertTrue(wrapped.getBody() instanceof AmqpValue);
+         assertInstanceOf(AmqpValue.class, wrapped.getBody());
          AmqpValue body = (AmqpValue) wrapped.getBody();
-         assertTrue(body.getValue() instanceof List);
+         assertInstanceOf(List.class, body.getValue());
          List<String> payload = (List) body.getValue();
          assertEquals(3, payload.size());
 
@@ -1090,9 +1078,9 @@ public class AmqpLargeMessageTest extends AmqpClientTestSupport {
          assertNotNull(received, "failed to read large AMQP message");
          MessageImpl wrapped = (MessageImpl) received.getWrappedMessage();
 
-         assertTrue(wrapped.getBody() instanceof AmqpSequence);
+         assertInstanceOf(AmqpSequence.class, wrapped.getBody());
          AmqpSequence body = (AmqpSequence) wrapped.getBody();
-         assertTrue(body.getValue() instanceof List);
+         assertInstanceOf(List.class, body.getValue());
          List<String> payload = (List) body.getValue();
          assertEquals(3, payload.size());
 
@@ -1196,14 +1184,7 @@ public class AmqpLargeMessageTest extends AmqpClientTestSupport {
          Queue queue = session.createQueue(testQueueName);
          MessageProducer producer = session.createProducer(queue);
          ObjectMessage msg = session.createObjectMessage();
-
-         StringBuilder builder = new StringBuilder();
-         for (int i = 0; i < payload; ++i) {
-            builder.append("A");
-         }
-
-         msg.setObject(builder.toString());
-
+         msg.setObject("A".repeat(payload));
          for (int i = 0; i < nMsgs; ++i) {
             msg.setIntProperty("i", (Integer) i);
             producer.send(msg);
@@ -1217,14 +1198,7 @@ public class AmqpLargeMessageTest extends AmqpClientTestSupport {
          Queue queue = session.createQueue(testQueueName);
          MessageProducer producer = session.createProducer(queue);
          TextMessage msg = session.createTextMessage();
-
-         StringBuilder builder = new StringBuilder();
-         for (int i = 0; i < payload; ++i) {
-            builder.append("A");
-         }
-
-         msg.setText(builder.toString());
-
+         msg.setText("A".repeat(payload));
          for (int i = 0; i < nMsgs; ++i) {
             msg.setIntProperty("i", (Integer) i);
             producer.send(msg);
@@ -1238,14 +1212,7 @@ public class AmqpLargeMessageTest extends AmqpClientTestSupport {
          Queue queue = session.createQueue(testQueueName);
          MessageProducer producer = session.createProducer(queue);
          BytesMessage msg = session.createBytesMessage();
-
-         StringBuilder builder = new StringBuilder();
-         for (int i = 0; i < payload; ++i) {
-            builder.append("A");
-         }
-
-         msg.writeBytes(builder.toString().getBytes(StandardCharsets.UTF_8));
-
+         msg.writeBytes("A".repeat(payload).getBytes(StandardCharsets.UTF_8));
          for (int i = 0; i < nMsgs; ++i) {
             msg.setIntProperty("i", (Integer) i);
             producer.send(msg);
