@@ -18,6 +18,7 @@ package org.apache.activemq.artemis.tests.integration.cluster.distribution;
 
 import org.apache.activemq.artemis.core.server.cluster.impl.MessageLoadBalancingType;
 import org.apache.activemq.artemis.tests.util.ActiveMQTestBase;
+import org.junit.jupiter.api.Test;
 
 public class SymmetricClusterWithDiscoveryTest extends SymmetricClusterTest {
 
@@ -30,6 +31,13 @@ public class SymmetricClusterWithDiscoveryTest extends SymmetricClusterTest {
       return false;
    }
 
+   @Override
+   @Test
+   public void testStartStopServers() throws Exception {
+      // When using discovery starting and stopping it too fast could have a race condition with UDP
+      doTestStartStopServers();
+   }
+
    @Override
    protected void setupCluster() throws Exception {
       setupCluster(MessageLoadBalancingType.ON_DEMAND);
@@ -61,8 +69,8 @@ public class SymmetricClusterWithDiscoveryTest extends SymmetricClusterTest {
     * This is like testStopStartServers but we make sure we pause longer than discovery group timeout
     * before restarting (5 seconds)
     */
-   public void _testStartStopServersWithPauseBeforeRestarting() throws Exception {
-      doTestStartStopServers(10000, 3000);
+   @Test
+   public void testStartStopServersWithPauseBeforeRestarting() throws Exception {
+      doTestStartStopServers();
    }
-
 }
