@@ -46,7 +46,7 @@ import org.apache.activemq.artemis.core.protocol.mqtt.MQTTUtil;
 import org.apache.activemq.artemis.core.server.Queue;
 import org.apache.activemq.artemis.core.settings.impl.AddressSettings;
 import org.apache.activemq.artemis.logs.AssertionLoggerHandler;
-import org.apache.activemq.artemis.tests.util.RandomUtil;
+import org.apache.activemq.artemis.utils.RandomUtil;
 import org.apache.activemq.artemis.utils.ReusableLatch;
 import org.apache.activemq.artemis.utils.Wait;
 import org.eclipse.paho.mqttv5.client.MqttAsyncClient;
@@ -63,7 +63,7 @@ import org.junit.jupiter.api.Timeout;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-/*
+/**
  * General tests for things not covered directly in the specification.
  */
 public class MQTT5Test extends MQTT5TestSupport {
@@ -73,7 +73,7 @@ public class MQTT5Test extends MQTT5TestSupport {
    @Test
    @Timeout(DEFAULT_TIMEOUT_SEC)
    public void testSimpleSendReceive() throws Exception {
-      String topic = RandomUtil.randomString();
+      String topic = RandomUtil.randomUUIDString();
 
       CountDownLatch latch = new CountDownLatch(1);
       MqttClient subscriber = createPahoClient("subscriber");
@@ -93,6 +93,31 @@ public class MQTT5Test extends MQTT5TestSupport {
       assertTrue(latch.await(500, TimeUnit.MILLISECONDS));
    }
 
+   @Test
+   @Timeout(DEFAULT_TIMEOUT_SEC)
+   public void testSimpleRetroSendReceive() throws Exception {
+      final String topic = RandomUtil.randomUUIDString();
+      server.getAddressSettingsRepository().addMatch(topic, new AddressSettings().setRetroactiveMessageCount(1));
+
+      MqttClient producer = createPahoClient("producer");
+      producer.connect();
+      producer.publish(topic, "myMessage".getBytes(StandardCharsets.UTF_8), 1, false);
+
+      CountDownLatch latch = new CountDownLatch(1);
+      MqttClient subscriber = createPahoClient("subscriber");
+      subscriber.connect();
+      subscriber.setCallback(new DefaultMqttCallback() {
+         @Override
+         public void messageArrived(String t, MqttMessage message) {
+            logger.info("Message received from topic {}, message={}", t, message);
+            assertEquals(topic.toString(), t);
+            latch.countDown();
+         }
+      });
+      subscriber.subscribe(topic, AT_LEAST_ONCE);
+      assertTrue(latch.await(500, TimeUnit.MILLISECONDS));
+   }
+
    @Test
    @Timeout(DEFAULT_TIMEOUT_SEC)
    public void testTopicNameEscape() throws Exception {
@@ -115,20 +140,20 @@ public class MQTT5Test extends MQTT5TestSupport {
       Wait.assertEquals(topic, receivedTopic::get, 500, 50);
    }
 
-   /*
+   /**
     * Ensure that the broker adds a timestamp on the message when sending via MQTT
     */
    @Test
    @Timeout(DEFAULT_TIMEOUT_SEC)
    public void testTimestamp() throws Exception {
-      final String DESTINATION = RandomUtil.randomString();
+      final String DESTINATION = RandomUtil.randomUUIDString();
 
       createJMSConnection();
       JMSContext context = cf.createContext();
       JMSConsumer consumer = context.createConsumer(context.createQueue(DESTINATION));
 
       long time = System.currentTimeMillis();
-      MqttClient producer = createPahoClient(RandomUtil.randomString());
+      MqttClient producer = createPahoClient(RandomUtil.randomUUIDString());
       producer.connect();
       producer.publish(DESTINATION, new byte[0], 1, false);
       producer.disconnect();
@@ -201,16 +226,16 @@ public class MQTT5Test extends MQTT5TestSupport {
       Wait.assertEquals(0L, () -> server.locateQueue(MQTTUtil.MQTT_SESSION_STORE).getMessageCount(), 5000, 100);
    }
 
-   /*
+   /**
     * Trying to reproduce error from https://issues.apache.org/jira/browse/ARTEMIS-1184
     */
    @Test
    @Timeout(DEFAULT_TIMEOUT_SEC)
    public void testAddressAutoCreation() throws Exception {
-      final String DESTINATION = RandomUtil.randomString();
+      final String DESTINATION = RandomUtil.randomUUIDString();
       server.getAddressSettingsRepository().addMatch(DESTINATION, new AddressSettings().setAutoCreateAddresses(true));
 
-      MqttClient producer = createPahoClient(RandomUtil.randomString());
+      MqttClient producer = createPahoClient(RandomUtil.randomUUIDString());
       producer.connect();
       producer.publish(DESTINATION, new byte[0], 0, false);
       producer.disconnect();
@@ -222,19 +247,19 @@ public class MQTT5Test extends MQTT5TestSupport {
    @Test
    @Timeout(DEFAULT_TIMEOUT_SEC)
    public void testAddressAutoCreationNegative() throws Exception {
-      final String DESTINATION = RandomUtil.randomString();
+      final String DESTINATION = RandomUtil.randomUUIDString();
       server.getAddressSettingsRepository().addMatch(DESTINATION, new AddressSettings().setAutoCreateAddresses(false));
 
-      MqttClient producer = createPahoClient(RandomUtil.randomString());
+      MqttClient producer = createPahoClient(RandomUtil.randomUUIDString());
       producer.connect();
       producer.publish(DESTINATION, new byte[0], 0, false);
       producer.disconnect();
       producer.close();
 
-      assertTrue(server.getAddressInfo(SimpleString.of(DESTINATION)) == null);
+      assertNull(server.getAddressInfo(SimpleString.of(DESTINATION)));
    }
 
-   /*
+   /**
     * There is no normative statement in the spec about supporting user properties on will messages, but it is implied
     * in various places.
     */
@@ -244,8 +269,8 @@ public class MQTT5Test extends MQTT5TestSupport {
       final byte[] WILL = RandomUtil.randomBytes();
       final String[][] properties = new String[10][2];
       for (String[] property : properties) {
-         property[0] = RandomUtil.randomString();
-         property[1] = RandomUtil.randomString();
+         property[0] = RandomUtil.randomUUIDString();
+         property[1] = RandomUtil.randomUUIDString();
       }
 
       // consumer of the will message
@@ -283,14 +308,14 @@ public class MQTT5Test extends MQTT5TestSupport {
       assertTrue(latch.await(2, TimeUnit.SECONDS));
    }
 
-   /*
+   /**
     * It's possible for a client to change their session expiry interval via the DISCONNECT packet. Ensure we respect
     * a new session expiry interval when disconnecting.
     */
    @Test
    @Timeout(DEFAULT_TIMEOUT_SEC)
    public void testExpiryDelayOnDisconnect() throws Exception {
-      final String CONSUMER_ID = RandomUtil.randomString();
+      final String CONSUMER_ID = RandomUtil.randomUUIDString();
 
       MqttAsyncClient consumer = createAsyncPahoClient(CONSUMER_ID);
       MqttConnectionOptions options = new MqttConnectionOptionsBuilder()
@@ -304,7 +329,7 @@ public class MQTT5Test extends MQTT5TestSupport {
       Wait.assertEquals(0, () -> getSessionStates().size(), 5000, 10);
    }
 
-   /*
+   /**
     * If the Will flag is false then don't send a will message even if the session expiry is > 0
     */
    @Test
@@ -328,8 +353,8 @@ public class MQTT5Test extends MQTT5TestSupport {
    @Test
    @Timeout(DEFAULT_TIMEOUT_SEC)
    public void testQueueCleanOnRestart() throws Exception {
-      String topic = RandomUtil.randomString();
-      String clientId = RandomUtil.randomString();
+      String topic = RandomUtil.randomUUIDString();
+      String clientId = RandomUtil.randomUUIDString();
 
       MqttClient client = createPahoClient(clientId);
       MqttConnectionOptions options = new MqttConnectionOptionsBuilder()
@@ -524,6 +549,11 @@ public class MQTT5Test extends MQTT5TestSupport {
       producer.publish(TOPIC, new byte[0], 1, false);
       assertTrue(ackLatch.await(2, TimeUnit.SECONDS));
 
+      // sanity send using fqqn as we can know the name of a shared sub
+      ackLatch.countUp();
+      producer.publish(TOPIC + "::" + SUB_NAME + "/" + TOPIC, new byte[0], 1, false);
+      assertTrue(ackLatch.await(2, TimeUnit.SECONDS));
+
       producer.disconnect();
       producer.close();
       consumer1.disconnect();
@@ -554,7 +584,7 @@ public class MQTT5Test extends MQTT5TestSupport {
 
       List<String> addresses = new ArrayList<>();
       for (int i = 0; i < MESSAGE_COUNT; i++) {
-         String address = prefix + "/" + RandomUtil.randomString();
+         String address = prefix + "/" + RandomUtil.randomUUIDString();
          addresses.add(address.replace('/', '.'));
          producer.publish(address, new MqttMessage());
       }
@@ -581,7 +611,7 @@ public class MQTT5Test extends MQTT5TestSupport {
    @Timeout(DEFAULT_TIMEOUT_SEC)
    public void testConnectionStealingDisabled() throws Exception {
       setAcceptorProperty("allowLinkStealing=false");
-      final String CLIENT_ID = RandomUtil.randomString();
+      final String CLIENT_ID = RandomUtil.randomUUIDString();
 
       MqttClient client = createPahoClient(CLIENT_ID);
       client.connect();
@@ -608,9 +638,9 @@ public class MQTT5Test extends MQTT5TestSupport {
    @Timeout(DEFAULT_TIMEOUT_SEC)
    public void testConnectionStealingOnMultipleAcceptors() throws Exception {
       int secondaryPort = 1884;
-      final String CLIENT_ID = RandomUtil.randomString();
+      final String CLIENT_ID = RandomUtil.randomUUIDString();
 
-      server.getRemotingService().createAcceptor(RandomUtil.randomString(), "tcp://localhost:" + secondaryPort);
+      server.getRemotingService().createAcceptor(RandomUtil.randomUUIDString(), "tcp://localhost:" + secondaryPort);
       server.getRemotingService().startAcceptors();
 
       MqttClient client = createPahoClient(CLIENT_ID);
@@ -634,9 +664,9 @@ public class MQTT5Test extends MQTT5TestSupport {
    @Timeout(DEFAULT_TIMEOUT_SEC)
    public void testConnectionStealingDisabledOnMultipleAcceptors() throws Exception {
       int secondaryPort = 1884;
-      final String CLIENT_ID = RandomUtil.randomString();
+      final String CLIENT_ID = RandomUtil.randomUUIDString();
 
-      server.getRemotingService().createAcceptor(RandomUtil.randomString(), "tcp://localhost:" + secondaryPort + "?allowLinkStealing=false");
+      server.getRemotingService().createAcceptor(RandomUtil.randomUUIDString(), "tcp://localhost:" + secondaryPort + "?allowLinkStealing=false");
       server.getRemotingService().startAcceptors();
 
       MqttClient client = createPahoClient(CLIENT_ID);
