@@ -104,7 +104,7 @@ public class CoreClientOverOneWaySSLTest extends ActiveMQTestBase {
       this.storeType = storeType;
       this.generateWarning = generateWarning;
       this.useKeystoreAlias = useKeystoreAlias;
-      suffix = storeType == null || storeType.length() == 0 ? storeProvider.toLowerCase() : storeType.toLowerCase();
+      suffix = storeType == null || storeType.isEmpty() ? storeProvider.toLowerCase() : storeType.toLowerCase();
       // keytool expects PKCS12 stores to use the extension "p12"
       if (suffix.equalsIgnoreCase("PKCS12")) {
          suffix = "p12";
@@ -137,7 +137,7 @@ public class CoreClientOverOneWaySSLTest extends ActiveMQTestBase {
    @TestTemplate
    public void testOneWaySSL() throws Exception {
       createCustomSslServer();
-      String text = RandomUtil.randomString();
+      String text = RandomUtil.randomUUIDString();
 
       tc.getParams().put(TransportConstants.SSL_ENABLED_PROP_NAME, true);
       tc.getParams().put(TransportConstants.TRUSTSTORE_PROVIDER_PROP_NAME, storeProvider);
@@ -165,7 +165,7 @@ public class CoreClientOverOneWaySSLTest extends ActiveMQTestBase {
    @TestTemplate
    public void testOneWaySSLwithSNI() throws Exception {
       createCustomSslServer("myhost\\.com");
-      String text = RandomUtil.randomString();
+      String text = RandomUtil.randomUUIDString();
 
       tc.getParams().put(TransportConstants.SSL_ENABLED_PROP_NAME, true);
       tc.getParams().put(TransportConstants.TRUSTSTORE_PROVIDER_PROP_NAME, storeProvider);
@@ -234,7 +234,7 @@ public class CoreClientOverOneWaySSLTest extends ActiveMQTestBase {
    @TestTemplate
    public void testOneWaySSLwithSNIOnlyOnTheClient() throws Exception {
       createCustomSslServer();
-      String text = RandomUtil.randomString();
+      String text = RandomUtil.randomUUIDString();
 
       tc.getParams().put(TransportConstants.SSL_ENABLED_PROP_NAME, true);
       tc.getParams().put(TransportConstants.TRUSTSTORE_PROVIDER_PROP_NAME, storeProvider);
@@ -263,7 +263,7 @@ public class CoreClientOverOneWaySSLTest extends ActiveMQTestBase {
    @TestTemplate
    public void testOneWaySSLwithSNIOnlyOnTheBroker() throws Exception {
       createCustomSslServer("myhost\\.com");
-      String text = RandomUtil.randomString();
+      String text = RandomUtil.randomUUIDString();
 
       tc.getParams().put(TransportConstants.SSL_ENABLED_PROP_NAME, true);
       tc.getParams().put(TransportConstants.TRUSTSTORE_PROVIDER_PROP_NAME, storeProvider);
@@ -291,7 +291,7 @@ public class CoreClientOverOneWaySSLTest extends ActiveMQTestBase {
    @TestTemplate
    public void testOneWaySSLwithTrustManagerPlugin() throws Exception {
       createCustomSslServer(null, null, false, null, TestTrustManagerFactoryPlugin.class.getName());
-      String text = RandomUtil.randomString();
+      String text = RandomUtil.randomUUIDString();
 
       tc.getParams().put(TransportConstants.SSL_ENABLED_PROP_NAME, true);
       tc.getParams().put(TransportConstants.TRUSTSTORE_PROVIDER_PROP_NAME, storeProvider);
@@ -322,7 +322,7 @@ public class CoreClientOverOneWaySSLTest extends ActiveMQTestBase {
    @TestTemplate
    public void testOneWaySSLwithURL() throws Exception {
       createCustomSslServer();
-      String text = RandomUtil.randomString();
+      String text = RandomUtil.randomUUIDString();
 
       String url = "tcp://127.0.0.1:61616?sslEnabled=true;trustStorePath=" + CLIENT_SIDE_TRUSTSTORE + ";trustStorePassword=" + PASSWORD;
       if (storeProvider != null && !storeProvider.equals(TransportConstants.DEFAULT_TRUSTSTORE_PROVIDER)) {
@@ -352,11 +352,9 @@ public class CoreClientOverOneWaySSLTest extends ActiveMQTestBase {
    @TestTemplate
    public void testOneWaySSLwithURLandMaskedPasswordProperty() throws Exception {
       createCustomSslServer();
-      String text = RandomUtil.randomString();
+      String text = RandomUtil.randomUUIDString();
 
       DefaultSensitiveStringCodec codec = PasswordMaskingUtil.getDefaultCodec();
-      Map<String, String> params = new HashMap<>();
-      codec.init(params);
 
       String masked = codec.encode(PASSWORD);
       String url = "tcp://127.0.0.1:61616?sslEnabled=true;trustStorePath=" + CLIENT_SIDE_TRUSTSTORE + ";trustStorePassword=" + masked + ";activemq.usemaskedpassword=true";
@@ -386,11 +384,9 @@ public class CoreClientOverOneWaySSLTest extends ActiveMQTestBase {
    @TestTemplate
    public void testOneWaySSLwithURLandMaskedPasswordENCSyntax() throws Exception {
       createCustomSslServer();
-      String text = RandomUtil.randomString();
+      String text = RandomUtil.randomUUIDString();
 
       DefaultSensitiveStringCodec codec = PasswordMaskingUtil.getDefaultCodec();
-      Map<String, String> params = new HashMap<>();
-      codec.init(params);
 
       String masked = codec.encode(PASSWORD);
 
@@ -422,7 +418,7 @@ public class CoreClientOverOneWaySSLTest extends ActiveMQTestBase {
    @TestTemplate
    public void testOneWaySSLUsingDefaultSslContext() throws Exception {
       createCustomSslServer();
-      String text = RandomUtil.randomString();
+      String text = RandomUtil.randomUUIDString();
 
       tc.getParams().put(TransportConstants.SSL_ENABLED_PROP_NAME, true);
       tc.getParams().put(TransportConstants.USE_DEFAULT_SSL_CONTEXT_PROP_NAME, true);
@@ -455,7 +451,7 @@ public class CoreClientOverOneWaySSLTest extends ActiveMQTestBase {
    @TestTemplate
    public void testOneWaySSLVerifyHost() throws Exception {
       createCustomSslServer();
-      String text = RandomUtil.randomString();
+      String text = RandomUtil.randomUUIDString();
 
       tc.getParams().put(TransportConstants.SSL_ENABLED_PROP_NAME, true);
       tc.getParams().put(TransportConstants.TRUSTSTORE_PROVIDER_PROP_NAME, storeProvider);
@@ -484,7 +480,7 @@ public class CoreClientOverOneWaySSLTest extends ActiveMQTestBase {
    @TestTemplate
    public void testOneWaySSLVerifyHostNegative() throws Exception {
       createCustomSslServer(true);
-      String text = RandomUtil.randomString();
+      String text = RandomUtil.randomUUIDString();
 
       tc.getParams().put(TransportConstants.SSL_ENABLED_PROP_NAME, true);
       tc.getParams().put(TransportConstants.TRUSTSTORE_PROVIDER_PROP_NAME, storeProvider);
@@ -507,7 +503,7 @@ public class CoreClientOverOneWaySSLTest extends ActiveMQTestBase {
    public void testOneWaySSLReloaded() throws Exception {
       createCustomSslServer();
       server.createQueue(QueueConfiguration.of(CoreClientOverOneWaySSLTest.QUEUE).setRoutingType(RoutingType.ANYCAST).setDurable(false));
-      String text = RandomUtil.randomString();
+      String text = RandomUtil.randomUUIDString();
 
       // create a valid SSL connection and keep it for use later
       tc.getParams().put(TransportConstants.SSL_ENABLED_PROP_NAME, true);
@@ -705,7 +701,7 @@ public class CoreClientOverOneWaySSLTest extends ActiveMQTestBase {
    @TestTemplate
    public void testOneWaySSLWithGoodClientCipherSuite() throws Exception {
       createCustomSslServer();
-      String text = RandomUtil.randomString();
+      String text = RandomUtil.randomUUIDString();
 
       tc.getParams().put(TransportConstants.SSL_ENABLED_PROP_NAME, true);
       tc.getParams().put(TransportConstants.TRUSTSTORE_PROVIDER_PROP_NAME, storeProvider);
@@ -741,7 +737,7 @@ public class CoreClientOverOneWaySSLTest extends ActiveMQTestBase {
    @TestTemplate
    public void testOneWaySSLWithGoodServerCipherSuite() throws Exception {
       createCustomSslServer(getSuitableCipherSuite(), null);
-      String text = RandomUtil.randomString();
+      String text = RandomUtil.randomUUIDString();
 
       tc.getParams().put(TransportConstants.SSL_ENABLED_PROP_NAME, true);
       tc.getParams().put(TransportConstants.TRUSTSTORE_PROVIDER_PROP_NAME, storeProvider);
@@ -776,7 +772,7 @@ public class CoreClientOverOneWaySSLTest extends ActiveMQTestBase {
    @TestTemplate
    public void testOneWaySSLWithGoodClientProtocol() throws Exception {
       createCustomSslServer();
-      String text = RandomUtil.randomString();
+      String text = RandomUtil.randomUUIDString();
 
       tc.getParams().put(TransportConstants.SSL_ENABLED_PROP_NAME, true);
       tc.getParams().put(TransportConstants.TRUSTSTORE_PROVIDER_PROP_NAME, storeProvider);
@@ -812,7 +808,7 @@ public class CoreClientOverOneWaySSLTest extends ActiveMQTestBase {
    @TestTemplate
    public void testOneWaySSLWithGoodServerProtocol() throws Exception {
       createCustomSslServer(null, "TLSv1.2");
-      String text = RandomUtil.randomString();
+      String text = RandomUtil.randomUUIDString();
 
       tc.getParams().put(TransportConstants.SSL_ENABLED_PROP_NAME, true);
       tc.getParams().put(TransportConstants.TRUSTSTORE_PROVIDER_PROP_NAME, storeProvider);
@@ -849,18 +845,16 @@ public class CoreClientOverOneWaySSLTest extends ActiveMQTestBase {
 
       String[] suites = getEnabledCipherSuites();
 
-      /**
-       * The JKS certs are generated using Java keytool using RSA and not ECDSA but the JVM prefers ECDSA over RSA so we have
-       * to look through the cipher suites until we find one that's suitable for us.
-       * If the JVM running this test is version 7 from Oracle then this cipher suite will will almost certainly require
-       * TLSv1.2 (which is not enabled on the client by default).
-       * See http://docs.oracle.com/javase/8/docs/technotes/guides/security/SunProviders.html#SunJSSEProvider for the
+      /*
+       * The JKS certs are generated using Java keytool using RSA and not ECDSA but the JVM prefers ECDSA over RSA so we
+       * have to look through the cipher suites until we find one that's suitable for us. If the JVM running this test
+       * is version 7 from Oracle then this cipher suite will will almost certainly require TLSv1.2 (which is not
+       * enabled on the client by default). See
+       * http://docs.oracle.com/javase/8/docs/technotes/guides/security/SunProviders.html#SunJSSEProvider for the
        * preferred cipher suites.
        */
 
-      /**
-       * JCEKS is essentially the same story as JKS
-       */
+      // JCEKS is essentially the same story as JKS
       for (int i = 0; i < suites.length; i++) {
          String suite = suites[i];
          String storeType = SSLSupport.getValidProviderAndType(this.storeProvider, this.storeType).getB();
@@ -943,7 +937,6 @@ public class CoreClientOverOneWaySSLTest extends ActiveMQTestBase {
       }
    }
 
-   // see https://jira.jboss.org/jira/browse/HORNETQ-234
    @TestTemplate
    public void testPlainConnectionToSSLEndpoint() throws Exception {
       createCustomSslServer();
